@@ -11,16 +11,20 @@ class PythonPackage(HitchPackage):
     name = "Python"
 
     PYTHON_VERSIONS = [
-        '2.1.3', '2.2.3', '2.3.7', '2.4', '2.4.1', '2.4.2', '2.4.3', '2.4.4', '2.4.5', '2.4.6',
-        '2.5', '2.5.1', '2.5.2', '2.5.3', '2.5.4', '2.5.5', '2.5.6',
+        #'2.1.3', '2.2.3', '2.3.7',
+        #'2.4', '2.4.1', '2.4.2', '2.4.3', '2.4.4', '2.4.5', '2.4.6',
+        #'2.5', '2.5.1', '2.5.2', '2.5.3', '2.5.4', '2.5.5', '2.5.6',
         '2.6.6', '2.6.7', '2.6.8', '2.6.9',
         '2.7', '2.7.1', '2.7.2', '2.7.3', '2.7.4',
         '2.7.5', '2.7.6', '2.7.7', '2.7.8', '2.7.9', '2.7.10', '2.7-dev',
-        '3.0.1', '3.1-dev', '3.1', '3.1.1', '3.1.2', '3.1.3', '3.1.4', '3.1.5',
-        '3.2', '3.2.1', '3.2.2', '3.2.3', '3.2.4', '3.2.5', '3.2.6','3.2-dev',
-        '3.3.0', '3.3-dev', '3.3.1', '3.3.2', '3.3.3', '3.3.4', '3.3.5', '3.3.6',
-        '3.4.0', '3.4-dev', '3.4.1', '3.4.2', '3.4.3', '3.5.0b1',
-        '3.5.0b2', '3.5.0b3', '3.5-dev',
+        #'3.0.1', '3.1-dev', '3.1', '3.1.1', '3.1.2', '3.1.3', '3.1.4', '3.1.5',
+        '3.2', '3.2.1', '3.2.2', '3.2.3', '3.2.4', '3.2.5', '3.2.6', #'3.2-dev',
+        '3.3.0',
+        #'3.3-dev',
+        '3.3.1', '3.3.2', '3.3.3', '3.3.4', '3.3.5', '3.3.6',
+        '3.4.0',
+        #'3.4-dev',
+        '3.4.1', '3.4.2', '3.4.3', '3.5.0b1', '3.5.0b2', '3.5.0b3', '3.5-dev',
     ]
 
     def __init__(self, python_version="2.7.10", directory=None, bin_directory=None):
